@@ -8,17 +8,13 @@ if TYPE_CHECKING:
 
 
 class Event(Protocol):
-    def clear(self) -> None:
-        ...
+    def clear(self) -> None: ...
 
-    def is_set(self) -> bool:
-        ...
+    def is_set(self) -> bool: ...
 
-    def set(self) -> None:
-        ...
+    def set(self) -> None: ...
 
-    def wait(self, timeout: Optional[float] = None) -> bool:
-        ...
+    def wait(self, timeout: Optional[float] = None) -> bool: ...
 
 
 @dataclass
